/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.distributedlog.function;

import scala.runtime.AbstractFunction1;

/**
 * Map Function return default value
 */
public class DefaultValueMapFunction<T, R> extends AbstractFunction1<T, R> {

    public static <T, R> DefaultValueMapFunction<T, R> of(R defaultValue) {
        return new DefaultValueMapFunction<T, R>(defaultValue);
    }

    private final R defaultValue;

    private DefaultValueMapFunction(R defaultValue) {
        this.defaultValue = defaultValue;
    }

    @Override
    public R apply(T any) {
        return defaultValue;
    }
}
